*Carola Binder
*September 17, 2020
*"Political Pressure on Central Banks"

clear
set more off

********Table I: Pressure Reports by Source Country and Central Bank Coverage
use NarrativeUncollapsed.dta, clear
gen EIUresisting=1 if (EIUPressure==1|EIUPressure==2)
gen EIUsuccumbing=1 if (EIUPressure==3)
gen BMIresisting=1 if (BMIPressure==1|BMIPressure==2)
gen BMIsuccumbing=1 if (BMIPressure==3)
tab EIUresisting 
tab EIUsuccumbing 
tab BMIresisting 
tab BMIsuccumbing


********Table II: Country and Central Bank Coverage 
use PanelQuarterly.dta, clear
*How many country-quarter observations? (4012)
sum P
*How many quarters? (34) How many central banks? (118)
tab cname if P!=.


********Table III: Political Pressure Transition Matrix
use PanelQuarterly.dta, clear
xtset id t
gen lindex =l.index
tab lindex index, row
label define indexl 0 "No mention" 1 "Resist" 2 "Succumb"
label values lindex indexl
label values index indexl
latab lindex index, row dec(1)


********Table IV: Correlation between Legal CBI Indices and Political Pressure Measures
use CrossSection.dta, clear
gen Garriga=CBI2010s
corrtab P shareP shareP1 shareP2 Garriga cuk*2010s overallind politicalin economicin, vars(4) obs sig


********Table V: Regressions of Political Pressure on CBI
use CrossSection.dta, clear
gen lowincome=1 if highincome==0
replace lowincome=0 if highincome==1
gen CBI_highincome=CBI2010s*highincome
gen CBI_lowincome=CBI2010s*lowincome
gen economic_lowincome=economicind*lowincome
gen political_lowincome=politicalind*lowincome
label var CBI_highincome "CBI*high income"
label var CBI_lowincome "CBI*low inc."
label var economic_low "Econ. autonomy*low inc."
label var political_low "Pol. autonomy*low inc."
label var politicalind "Political autonomy"
label var economicind "Economic autonomy"
label var lnRGDPpercapita2010s "ln(RGDPpercap)"
gen CBI_lnRGDP=CBI2010s*lnRGDPpercapita2010s
label var CBI_lnRGDP "CBI*ln(RGDPpercap)"
gen lnCBI=ln(CBI2010s)
gen CBISq=CBI2010s^2

eststo clear
eststo: quietly reg shareP CBI2010s, r
eststo: quietly reg shareP CBI2010s CBISq, r
eststo: quietly reg shareP lnCBI, r
eststo: quietly reg shareP CBI2010s CBI_lowincome lowincome, r
eststo: quietly reg shareP1 CBI2010s CBI_lowincome lowincome, r
eststo: quietly reg shareP2 CBI2010s CBI_lowincome lowincome, r
eststo: quietly reg shareP economicind politicalind  economic_lowincome political_lowincome lowincome, r
esttab


********Table VI: Regression of Inflation Tax on CBI and Political Pressure
use CrossSection.dta, clear
eststo clear
eststo: quietly reg InflationTax2010s CBI2010s shareP, r
eststo: quietly reg InflationTax2010s CBI2010s shareP InflationTax2000s TurnoverIrregular2010s, r
eststo: quietly reg InflationTax2010s CBI2010s P1 P2 InflationTax2000s TurnoverIrregular2010s, r
eststo: quietly reg InflationTax2010s economicind politicalind shareP TurnoverIrregular2010s, r
esttab



********Table VII: Political Pressure and Inflation Persistence
use PanelQuarterly.dta, clear
egen pmax=max(index), by(cname)
egen shareP=mean(P), by(cname)
xtset id t
gen lpi=l.piCPI
drop if year<2010
gen pmax1=(pmax==1) if pmax!=.
gen pmax2=(pmax==2) if pmax!=.
gen lpi_pmax1=lpi*pmax1
gen lpi_pmax2=lpi*pmax2
gen lpi_shareP=lpi*shareP

eststo clear
eststo: quietly xtreg piCPI lpi if index!=., fe
eststo: quietly xtreg piCPI lpi lpi_pmax1 lpi_pmax2, fe
eststo: quietly xtreg piCPI lpi lpi_shareP, fe
esttab 


********Table VIII: Political Characteristics and Pressure on the Central Bank
use PanelQuarterly.dta, clear
xtset id t
*Exclude multi-country monetary unions 
foreach stub in execrel gov1nat execnat execrlc gov1rlc author allhouse system military checks checks_lax eie liec polity2 opp1rlc opp1nat polar oppfrac auton state stconst {
replace `stub'=. if cname=="ECB"|cname=="BCEAO"|cname=="BEAC"|cname=="ECCB"
}
replace execrlc=. if execrlc==0
replace gov1rlc=. if gov1rlc==0
replace opp1rlc=. if opp1rlc==0
*Polity score
tab index if polity2<4
tab index if polity2>=4 & polity2!=.
*Electoral competitiveness
tab index if eiec<4
tab index if eiec>=4 & eiec!=.
*Checks and balances
tab index if checks==1
tab index if checks>1 & checks!=.
*Whether executive party controls all houses
tab index if allhouse==1
tab index if allhouse==0
*Whether state government is locally elected
tab index if state==0
tab index if state==1|state==2
*Presidential or parliamentary
tab index if system==2
tab index if system==0
*Executive party left, right, or center
tab index if execrlc==3
tab index if execrlc==2
tab index if execrlc==1
*Executive nationalist
tab index if execnat==1
tab index if execnat==0
*Largest party nationalist
tab index if gov1nat==1
tab index if gov1nat==0
*Whether executive is from military
tab index if military==1
tab index if military==0


********Table IX: Political Pressure Following IMF Recommendations about CBI
use PanelYearly.dta, clear
xtset id year
gen lP=l.P
gen lIMFCBI=l.IMFCBI
label var lIMFCBI "IMF$ _{t-1}$"
gen lInflationTax=l.InflationTax
gen lUnemployment=l.Unemployment
gen DelayedArticleIV=(cname=="Venezuela"|cname=="Eritrea"|cname=="Syria"|cname=="Libya"|cname=="Yemen"|cname=="Burundi"|cname=="Haiti"|cname=="Congo, Republic of"|cname=="Congo, Democratic Republic of / Za")

eststo clear
eststo: quietly xtreg P lIMFCBI, fe
eststo: quietly xtreg P lIMFCBI if DelayedArticleIV!=1, fe
eststo: quietly xtreg P lP lIMFCBI, fe
eststo: quietly xtreg P lP lIMFCBI lInflationTax lUnemployment, fe
esttab 


********Figure I: Central Bank Pressure Measures over Time
use TimeSeries.dta, clear
twoway tsline P S, scale(1.4) recast(bar) xtitle("") ytitle("Number of Central Banks") xlabel(, format(%tqCCYY)) lpattern(solid dash) lwidth(medium thick medium) legend(symxsize(6) ring(0) bplacement(neast) cols(1) label(1 "Facing Pressure (Cat. 1 or 2)") label(2 "Succumbers (Cat. 2)"))
graph export Figure1.png, replace


********Figure II: Comparison with de Facto CBI Measures
use CrossSection.dta, clear

foreach stub in AlpandaEstimate Questionnaire {
	*Drop the monetary unions
	replace `stub'=. if cname=="ECB"|cname=="BCEAO"|cname=="BEAC"|cname=="ECCB"
}
foreach stub in AlpandaEstimate TurnoverIrregular2010s Questionnaire {
	*Scale the different de facto measures
	quietly sum `stub'
	gen norm`stub'=(`stub'-r(mean))/r(sd)
}
*Re-sign for Alpanda and Turnover so that positive indicates higher de facto CBI
replace normAlpand=-1*normAlpand
replace normTur=-1*normTur
label var normAlp "Alpanda and Honig"
label var normTur "Turnover"
label var normQue "CWN Questionnaire"
graph bar normA normT normQ, over(Type) scale(1.3) legend(size(3) symxsize(6) label(1 "Alpanda and Honig 2010") label(2 "Turnover") label(3 "Cukierman et al. 1992 questionnaire") cols(1) ring(0) bplacement(west)) 
graph export Figure2.png, replace


********Figure III: Response of Inflation to Political Pressure
*Uses code modified from Oscar Jorda's webpage accessed here: https://sites.google.com/site/oscarjorda/home/local-projections
use PanelQuarterly.dta, clear
keep if year>2009
xtset id t
gen lpi=l.piCPI
rename piCPI Inflation
local indvars Cat1 Cat2 Unemployment IP lpi
local depvars Inflation
local horizon 12
**Variables to store the R^2 from the regressions
foreach stub in `depvars' {
gen r2_`stub'=.
}

foreach ind in `indvars' {
foreach stub in `depvars' {
***** Variables to store the impulse response (vector of betas from the LP regressions) and standard errors
gen b_`stub'`ind'=.
gen se_`stub'`ind'=.
}
}

foreach stub in `depvars' {
	forvalues i=0/`horizon' {	
	* LP regression
	quietly xtreg f`i'.`stub' `indvars' lpi, fe
	eststo ols_`stub'`i'
	replace r2_`stub'=e(r2_o) if _n == `i'+1
	
	foreach ind in `indvars' {
	replace b_`stub'`ind'  = _b[`ind'] if _n == `i'+1
	replace se_`stub'`ind' = _se[`ind'] if _n == `i'+1
	}
	}
}
gen Quarters = _n-1 if _n <= `horizon' +1
* zero line
gen zero = 0 if _n <= `horizon' +1
foreach ind in `indvars' {
	foreach stub in `depvars' {
***** create confidence bands****
	scalar sig1 = 0.05	 // specify significance level
	scalar sig2 = 0.3	 // specify significance level

	gen up_`stub'`ind' = b_`stub'`ind' + invnormal(1-sig1/2)*se_`stub'`ind' if _n <= (`horizon' + 1)
	gen dn_`stub'`ind' = b_`stub'`ind' - invnormal(1-sig1/2)*se_`stub'`ind' if _n <= (`horizon' + 1)

	gen up2_`stub'`ind' = b_`stub'`ind' + invnormal(1-sig2/2)*se_`stub'`ind' if _n <= (`horizon' + 1)
	gen dn2_`stub'`ind' = b_`stub'`ind' - invnormal(1-sig2/2)*se_`stub'`ind' if _n <= (`horizon' + 1)

	twoway (rarea up_`stub'`ind' dn_`stub'`ind'  Quarters, ///
	fcolor(gs12) lcolor(white) lpattern(solid)) ///
	(rarea up2_`stub'`ind' dn2_`stub'`ind'  Quarters, ///
	fcolor(gs10) lcolor(white) lpattern(solid)) ///
	(line b_`stub'`ind' Quarters, lcolor(blue) ///
	lpattern(solid) lwidth(thick)) /// 
	(line zero Quarters, lcolor(black)), ///
	title("`ind'-->`stub'", color(black) size(medium)) ///
	ytitle(, size(medsmall)) xtitle("Quarters", size(medsmall)) ///
	graphregion(color(white)) plotregion(color(white)) tlabel(0(3)12) ylabel(-5(5)10) scale(2) ///
	legend(off) name(`stub'`ind', replace)
	graph save   `stub'`ind'_LP.gph, replace
	}
}
graph close
graph combine InflationCat1_LP.gph InflationCat2_LP.gph, cols(2)
graph display, ysize(4) xsize(10)
graph export Figure3.png, replace


********Appendix Table A1: Comparison of Discussions of Political Pressure by EIU and BMI 
use PanelQuarterly.dta, clear
gen lBMIP=l.BMIP
gen fBMIP=f.BMIP
bys EIUP: sum lBMIP BMIP fBMIP


********Appendix Table A2: Comparison of Discussions of Political Pressure by Source
use PanelQuarterly.dta, clear
collapse (max) EIUP BMIP IHSP FSWP, by(cname)
bys EIUP: sum BMIP IHSP FSWP

